From 6c36bde47167d8f83df37aa38f120549d629dacb Mon Sep 17 00:00:00 2001
From: DerGrumpf
Date: Wed, 26 Mar 2025 21:59:46 +0100
Subject: [PATCH] Added: Spotify
---
home/programs/media.nix | 2 ++
modules/system.nix | 37 ++++++++++++++++++++++++-------------
2 files changed, 26 insertions(+), 13 deletions(-)
diff --git a/home/programs/media.nix b/home/programs/media.nix
index f38d4ff..682ee1a 100644
--- a/home/programs/media.nix
+++ b/home/programs/media.nix
@@ -15,6 +15,8 @@
pulsemixer
# images
imv
+ # Apps
+ spotify
];
programs = {
diff --git a/modules/system.nix b/modules/system.nix
index 26096e0..97031d0 100644
--- a/modules/system.nix
+++ b/modules/system.nix
@@ -20,29 +20,30 @@
# customise /etc/nix/nix.conf declaratively via `nix.settings`
nix.settings = {
# enable flakes globally
- experimental-features = ["nix-command" "flakes"];
+ experimental-features = ["nix-command" "flakes"];
+ auto-optimise-store = true;
+ substituters = [
+ "https://cache.nixos.org"
+ "https://hyprland.cachix.org"
+ ];
- substituters = [
- "https://cache.nixos.org"
- "https://hyprland.cachix.org"
- ];
-
- trusted-public-keys = [
- "cache.nixos.org-1:6NCHdD59X431o0gWypbMrAURkbJ16ZPMQFGspcDShjY="
- "hyprland.cachix.org-1:a7pgxzMz7+chwVL3/pzj6jIBMioiJM7ypFP8PwtkuGc="
- ];
- builders-use-substitutes = true;
+ trusted-public-keys = [
+ "cache.nixos.org-1:6NCHdD59X431o0gWypbMrAURkbJ16ZPMQFGspcDShjY="
+ "hyprland.cachix.org-1:a7pgxzMz7+chwVL3/pzj6jIBMioiJM7ypFP8PwtkuGc="
+ ];
+ builders-use-substitutes = true;
};
# do garbage collection weekly to keep disk usage low
nix.gc = {
automatic = lib.mkDefault true;
dates = lib.mkDefault "weekly";
- options = lib.mkDefault "--delete-older-than 7d";
+ options = lib.mkDefault "--delete-older-than +3";
};
# Allow unfree packages
nixpkgs.config.allowUnfree = true;
+ nixpkgs.config.allowBroken = true;
# Set your time zone.
time.timeZone = "Europe/Berlin";
@@ -197,7 +198,10 @@
# Virtualisation
podman-compose # docker-compose alternative
dive # docker layer viewer
- podman-tui # status of containers in terminal
+ podman-tui # status of containers in terminal
+ podman-desktop # Desktop client
+ tailscale # Vpn
+ grayscale
];
# Enable sound with pipewire.
@@ -225,6 +229,13 @@
# no need to redefine it in your config for now)
#media-session.enable = true;
};
+
+ displayManager.autoLogin = {
+ enable = true;
+ user = "phil";
+ };
+
+ tailscale.enable = true;
udev.packages = with pkgs; [gnome.gnome-settings-daemon];
};